#===============================================================================
#                            U N C L A S S I F I E D
#===============================================================================
# Copyright (c) Northrop Grumman Corporation 2021 -- ALL RIGHTS RESERVED
#===============================================================================
#
#===============================================================================
# EXPORT REGULATIONS (EAR99)
#===============================================================================
# DISCLOSURE: 
#
# Warning - This data is subject to the Export Administration Act (Title 22 
# U.S.C. App. 2401 et seq.), as amended. The implementing regulation for 
# this statute is the Export Administration Regulations (EAR) (15 C.F.R.
# 730-774). It may not be transferred, either in its original form, derivative 
# documents, or after being incorporated into other data without first 
# obtaining approval from the U.S. government or as otherwise authorized by 
# U.S. law and regulations. 
#===============================================================================

%define ifdef()     %if %{expand:%%{?%{1}:1}%%{!?%{1}:0}}
%define defaultRel  0.0.%(date "+%y%m%d%H%M")

# Note: Cannot use single percent signs in comments as it causes issues with
#       rpmbuild. Therefore everywhere %% is used in a comment it means a
#       single percent in code.

# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
# Parse arguments
# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
# Set the release of the RPM according to the value of the 'trueRel' input
# variable, or use a string constant
%ifdef trueRel
    %define rel %{trueRel}
%else
    %define rel %{defaultRel}
%endif

# Specify the path to the sourceForEnvScript
%ifdef _sourceForEnvScript
    # Do nothing. Should already be set
%else
    # Guess on path to continuous_integration repository cloned locally
    %define _sourceForEnvScript ~/git/continuous_integration/resources/sourceForCIEnv.sh
%endif

# Specify the .snaenv file to use to configure the build environment
%ifdef _envfile
    # Do nothing; allows for override to be passed in from the external rpmbuild call if needed
%else
    %define _envfile /usr/share/SNA/config/sna_x86_64_env/x86_64_release.snaenv
%endif

# Set the install directory name according to the value of the 'installprefix'
# input variable, or use a string constant
%ifdef installprefix
    # Do nothing. Should already be set
%else
    %define installprefix /usr/share/SNA_Apps
%endif

# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
# Set up variables
# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
# Uncomment to disable the debuginfo package
#%define debug_package %{nil}

# CentOS 7 uses ".el7.centos" as %%dist; overwrite this to be ".el7"
%if 0%{?rhel} == 7
    %define dist .el7
%endif

# Disable rpath checking
%define __arch_install_post /usr/lib/rpm/check-buildroot

# DDS specific variables
%define ddsFlag %{nil}
%define summaryFlag for use with RTI DDS
%define descFlag Built with RTI DDS
%if 0%{?opendds} == 1
    %define ddsFlag -opendds
    %define summaryFlag for use with OpenDDS
    %define descFlag Built with OpenDDS
%endif

# CMake project name (where files will get generated)
%define cmakeProjectName BasicPubSub

# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
# Define packages
# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
Name:           %{cmakeProjectName}%{ddsFlag}
Version:        2.1.1
Release:        %{rel}%{?dist}
Summary:        Binary Package for %{name}
License:        NGC EULA
AutoReqProv:    no
Prefix:         %{installprefix}
BuildRequires:  sna2-core%{ddsFlag}-devel = %{version}
Requires:       sna2-core%{ddsFlag} = %{version}

%package devel
Summary:        Devel package for %{name}
Group:          Development/Libraries
AutoReqProv:    no
BuildArch:      noarch
Requires:       %{name} = %{version}
Requires:       sna2-core%{ddsFlag}-devel = %{version}

# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
# Describe packages
# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
%description
Binary Package for %{name}. Further description should go here.

%description devel
This package contains headers and cmake descriptors required to build
applications that use the %{name} package.

# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
# Build packages
# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
%prep

%build
# The sourceForCIEnv.sh script will be provided by the Jenkins shared library imported in the
# Jenkinsfile and passed through rpmbuild as %%{_sourceForEnvScript}. If you wish to build this
# RPM locally, you must have the continuous_integration repo cloned and point this spec directly
# to the sourceForCIEnv.sh script.
%if 0%{?opendds} == 1
    source %{_sourceForEnvScript} -w %{_sourcedir} -t %{_envfile} \
        -o "SNA=SNA" \
        -o "DDS=OpenDDS" \
        -o "COMPONENT_FRAMEWORK=AXCIOMA" \
        -o "Installation Support=Prefer workspace libraries" \
        -o "Compiler=Linux x86_64 GCC"
%else
    source %{_sourceForEnvScript} -w %{_sourcedir} -t %{_envfile}
%endif

cmake3 \
    -G "Eclipse CDT4 - Unix Makefiles" \
    -DCMAKE_BUILD_TYPE=RelWithDebInfo \
    -DOPTION_SNA_FATAL_WARNINGS=ON \
    -DOPTION_SNA_INSTALL_SNA=ON \
    -DOPTION_SNA_INSTALL_EXAMPLE=ON \
    -DOPTION_SNA_CREATE_DEBUGINFO=OFF \
    -DCMAKE_INSTALL_PREFIX="%{installprefix}" \
    %{_sourcedir}

%{make_build}

%install
%{make_install}

# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
# Allocate files
# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
%files
%defattr(755, root, root, 755)
%{installprefix}/lib/*
%{installprefix}/installed_apps/%{cmakeProjectName}/

%files devel
%defattr(755, root, root, 755)
%{installprefix}/include/cmake/*
%{installprefix}/include/%{cmakeProjectName}/

# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
# Define RPM scripts (%%pre and %%post sections)
# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -

#===============================================================================
#                            U N C L A S S I F I E D
#===============================================================================

